.. image:: https://badge.fury.io/py/psa-prizes.svg
  :target: https://pypi.org/project/psa-prizes

.. image:: https://github.com/tostenzel/psa-prizes/workflows/Continuous%20Integration/badge.svg?branch=master
  :target: https://github.com/tostenzel/psa-prizes/actions

.. image:: https://readthedocs.org/projects/psa-prizes/badge/?version=latest
   :target: https://psa-prizes.readthedocs.io/en/latest/?badge=latest

.. image:: https://codecov.io/gh/tostenzel/psa-prizes/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/tostenzel/psa-prizes

.. image:: https://api.codacy.com/project/badge/Grade/87ad6f0069fd45d9afd5ad97a579329b
   :alt: Codacy Badge
   :target: https://app.codacy.com/manual/tostenzel/psa-prizes?utm_source=github.com&utm_medium=referral&utm_content=tostenzel/psa-prizes&utm_campaign=Badge_Grade_Dashboard